// Copyright 2016 The LUCI Authors.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package utils

import (
	"testing"

	. "github.com/smartystreets/goconvey/convey"
)

func TestPem(t *testing.T) {
	Convey("DumpPEM/ParsePEM roundtrip", t, func() {
		data := []byte("blah-blah")
		back, err := ParsePEM(DumpPEM(data, "DATA"), "DATA")
		So(err, ShouldBeNil)
		So(back, ShouldResemble, data)
	})

	Convey("ParsePEM wrong header", t, func() {
		data := []byte("blah-blah")
		_, err := ParsePEM(DumpPEM(data, "DATA"), "NOT DATA")
		So(err, ShouldNotBeNil)
	})

	Convey("ParsePEM not a PEM", t, func() {
		_, err := ParsePEM("blah-blah", "NOT DATA")
		So(err, ShouldNotBeNil)
	})
}
